require_dependency "jobshop/application_controller"

module Jobshop
  class EmployeesController < ApplicationController
    def index
      @active_employees = current_organization.employees
        .merge(Jobshop::Employee.active).eager_load(:departments)
    end

    def new
      build_employee do |employee|
        render :new, locals: { employee: employee }
      end
    end

    def create
      respond_to do |format|
        build_employee(employee_params) do |employee|
          if employee.save
            format.html {
              redirect_to(employees_path, flash: { notice: "Created Employee" })
            }
          else
            format.html { render :new, locals: { employee: employee } }
          end
        end
      end
    end

    def edit
      find_employee do |employee|
        render :edit, locals: { employee: employee }
      end
    end

    def update
      respond_to do |format|
        Wisper.subscribe(Jobshop::AssignmentListener.new(current_user)) do
          find_employee do |employee|
            if employee.update(employee_params)
              format.html {
                redirect_to(employee_path(employee),
                            flash: { notice: "Updated Employee" })
              }
            else
              format.html { render :edit, locals: { employee: employee } }
            end
          end
        end
      end
    end

    def show
      find_employee do |employee|
        render :show, locals: { employee: employee }
      end
    end

    private def build_employee(attrs = {})
      employee = current_organization.employees.build(attrs)

      yield employee
    end

    private def find_employee
      employee = current_organization.employees.where(id: params[:id]).first

      yield employee
    end

    private def employee_params
      params.require(:employee)
        .permit(:forename, :surname, :email, department_ids: [ ],
                employments_attributes: [ :id, :started_on, :ended_on ])
    end
  end
end
