require_dependency "jobshop/application_controller"

module Jobshop
  class RFQsController < ApplicationController
    def edit
      find_rfq do |rfq|
        render :edit, locals: { rfq: rfq }
      end
    end

    def update
      respond_to do |format|
        Wisper.subscribe(Jobshop::AssignmentListener.new(current_user)) do
          find_rfq do |rfq|
            if rfq.update(rfq_params)
              format.html {
                redirect_to(edit_rfq_path(rfq),
                            flash: { notice: "RFQ Saved Successfully" })
              }
            else
              format.html { render :edit, locals: { rfq: rfq } }
            end
          end
        end
      end
    end

    private def find_rfq
      rfq = current_organization.rfqs.includes(lines: :quantities)
        .where(id: params[:id])
        .references(:rfqs)
        .merge(Jobshop::RFQ::Line.order(identifier: :asc))
        .merge(Jobshop::RFQ::Line::Quantity.order(quantity: :asc))
        .first

      yield rfq
    end

    private def rfq_params
      params.require(:rfq)
        .permit(lines_attributes: [
          :id, :identifier, :description, :_destroy, assignee_ids: [ ],
          quantities_attributes: [
            :id, :organization_id, :rfq_id, :rfq_line_id, :quantity_id, :quantity
          ]
      ])
    end
  end
end
