# frozen_string_literal: true

module Jobshop # :nodoc:
  class Customer::Contact < ApplicationRecord
    belongs_to :organization, inverse_of: :customer_contacts

    belongs_to :customer, inverse_of: :contacts

    validates :email,
      presence:   { if: :email_required? },
      format:     { if: :email_required?, with: /\A[^@\s]+@[^@\s]+\z/ },
      uniqueness: { if: :email_changed?, scope: :organization_id,
        case_sensitive: false }

    def full_name
      @name = [ forename, surname ].join(" ")
    end

    private def email_required?
      true
    end
  end
end
