# frozen_string_literal: true

module Jobshop
  class Employment < ApplicationRecord
    include Auditing

    belongs_to :organization, -> { readonly }, inverse_of: :employments

    belongs_to :employee, inverse_of: :employments

    default_scope { order(ended_on: :desc, started_on: :desc) }

    scope :active, -> {
      where(ended_on: nil)
    }

    scope :inactive, -> {
      where.not(ended_on: nil)
    }

    before_validation(on: :create) do
      self.organization ||= employee.organization
    end
  end
end
