# frozen_string_literal: true

module Jobshop
  class Inspection::BooleanCriterion < ApplicationRecord
    belongs_to :organization, -> { readonly }

    belongs_to :report, -> { readonly }

    has_one :criterion, -> (boolean_criterion) {
      where({
        organization_id: boolean_criterion.organization_id,
        report_id: boolean_criterion.report_id
      })
    }, as: :criterion, autosave: true, dependent: :destroy,
    inverse_of: :criterion

    def criterion
      super || build_criterion
    end

    delegate :name, :name=, :position, :position=, to: :criterion

    def tolerance
      @tolerance ||= condition
    end

    def unit
      "boolean".freeze
    end

    def pass?(value)
      ![ false, 0, "0", "f", "F", "false", "FALSE", "off", "OFF" ].include?(value)
    end

    # Generate a random value that has a 90% chance of being in spec.
    # TODO: This needs to go in the tests somewhere, not really in the model.
    # :nocov:
    def random
      rand(100) < 10
    end
    # :nocov:
  end
end
