# frozen_string_literal: true

module Jobshop
  class Inspection::Report < ApplicationRecord
    belongs_to :organization, -> { readonly }, inverse_of: :inspection_reports

    has_many :criteria, -> (report) {
      where({ organization_id: report.organization_id }) #.includes(:criterion)
        .order(:position)
    }

    has_many :boolean_criteria, -> (report) {
      rewhere({ organization_id: report.organization_id, report_id: report.id })
    }, through: :criteria, source: :criterion,
    source_type: "Jobshop::Inspection::BooleanCriterion"

    has_many :deviation_criteria, -> (report) {
      rewhere({ organization_id: report.organization_id, report_id: report.id })
    }, through: :criteria, source: :criterion,
    source_type: "Jobshop::Inspection::DeviationCriterion"

    has_many :limit_criteria, -> (report) {
      rewhere({ organization_id: report.organization_id, report_id: report.id })
    }, through: :criteria, source: :criterion,
    source_type: "Jobshop::Inspection::LimitCriterion"
  end
end
