# frozen_string_literal: true

module Jobshop
  class RFQ::Line < ApplicationRecord
    belongs_to :organization, -> { readonly }

    belongs_to :rfq, -> { readonly }, inverse_of: :lines

    has_many :assignments, dependent: :destroy, inverse_of: :line

    has_many :assignees, through: :assignments, source: :assigned_to

    has_many :quantities, dependent: :destroy, inverse_of: :line

    scope :unassigned, -> {
      left_outer_joins(:assignments)
        .where(jobshop_rfq_line_assignments: { line_id: nil })
    }

    accepts_nested_attributes_for :quantities, reject_if: proc { |attributes|
      attributes["quantity"].blank?
    }, allow_destroy: true

    before_validation(on: :create) do
      self.organization ||= rfq.organization
    end
  end
end
