# frozen_string_literal: true

module Jobshop
  class Thing < ApplicationRecord
    belongs_to :organization, -> { readonly }, inverse_of: :things

    belongs_to :collection, -> { readonly }, inverse_of: :things

    validates :name, presence: true,
      uniqueness: { scope: :organization_id, case_sensitive: false }

    validates :custom_fields, json: { message: -> (errors) { errors },
                                      schema: -> { my_schema },
                                      options: { errors_as_objects: true } }

    def my_schema
      # TODO: Because shoulda-matchers doesn't properly recreate the test
      # subject this has the return {} when collection is nil. Collection will
      # only ever be nil during this test. Once the proper fk constraint is
      # added to the db, the test in question will raise an exception and a new
      # solution will need to be found.
      collection && collection.schema || {}
    end
  end
end
