# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateEmployees < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_employees_table
    create_employments_table
  end

  private def create_employees_table
    create_table_with_auditing :jobshop_employees, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :user, type: :uuid, foreign_key: { to_table: :jobshop_users }

      t.citext :email, null: false

      t.string :forename
      t.string :surname

      t.timestamps
    end

    fk_organization :jobshop_employees

    foreign_key :jobshop_employees, :jobshop_users,
      { organization_id: :organization_id, user_id: :id }
  end

  private def create_employments_table
    create_table_with_auditing :jobshop_employments, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :employee, type: :uuid, null: false,
        foreign_key: { to_table: :jobshop_employees }

      t.string :title, null: false, default: ""

      t.date :started_on, default: { expr: "('now'::text)::date" }
      t.date :ended_on

      t.timestamps
    end

    fk_organization :jobshop_employments

    foreign_key :jobshop_employments, :jobshop_employees,
      { organization_id: :organization_id, employee_id: :id }

    execute <<~SQL
      ALTER TABLE
        jobshop_employments
      ADD
        CONSTRAINT no_overlapping_employments
          EXCLUDE USING gist (
            organization_id WITH =,
            employee_id WITH =,
            daterange(started_on, ended_on) WITH &&
          );
    SQL
  end
end
