# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateOrders < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_orders_table
    create_order_lines_table
  end

  private def create_orders_table
    create_table_with_auditing :jobshop_orders, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :customer, type: :uuid, null: false,
        foreign_key: { to_table: :jobshop_customers }

      t.string :number
      t.index %i[ organization_id number ], unique: true

      t.timestamps
    end

    fk_organization :jobshop_orders

    foreign_key :jobshop_orders, :jobshop_customers,
      { organization_id: :organization_id, customer_id: :id }
  end

  private def create_order_lines_table
    create_table_with_auditing :jobshop_order_lines, primary_key: %i[
      organization_id order_id id
    ] do |t|
      t.references :product, type: :uuid, null: false,
        foreign_key: { to_table: :jobshop_products }

      t.timestamps
    end

    fk_organization :jobshop_order_lines

    add_index :jobshop_order_lines, %i[ organization_id product_id ]

    foreign_key :jobshop_order_lines, :jobshop_orders,
      { organization_id: :organization_id, order_id: :id }

    foreign_key :jobshop_order_lines, :jobshop_products,
      { organization_id: :organization_id, product_id: :id }
  end
end
