# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateRoles < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_roles_table
    create_role_assignments_table
#    create_abilities_table
  end

  private def create_roles_table
    create_table_with_auditing :jobshop_roles, primary_key: %i[
      organization_id id
    ] do |t|
      t.citext :name

      t.references :resource, polymorphic: true

      t.index %i[ organization_id name ], unique: true
      t.index %i[ organization_id name resource_type resource_id ],
        name: :idx_jobshop_roles_organization_name_type_id

      t.timestamps
    end

    fk_organization :jobshop_roles
  end

  private def create_role_assignments_table
    create_table_with_auditing :jobshop_role_assignments, primary_key: %i[
        organization_id id
    ] do |t|
      t.references :user, type: :uuid, foreign_key: { to_table: :jobshop_users }
      t.references :role, type: :uuid, foreign_key: { to_table: :jobshop_roles }

      t.index %i[ organization_id user_id role_id ], unique: true,
        name: :idx_jobshop_users_roles_organization_id_user_id_role_id
    end

    fk_organization :jobshop_role_assignments
  end

  private def create_abilities_table
    create_table_with_auditing :jobshop_abilities, primary_key: %i[
      organization_id id
    ] do |t|
      t.string :resource_class, null: false
      t.integer :action
      t.uuid :resource_id
      t.index %i[ organization_id resource_class action resource_id ],
        unique: true, name: :idx_jobshop_abilities_secondary_key
    end

    fk_organization :jobshop_abilities
  end
end
