# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateThings < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_collections_table
    create_things_table
  end

  private def create_collections_table
    create_table_with_auditing :jobshop_collections, primary_key: %i[
      organization_id id
    ] do |t|
      t.citext :name
      t.index %i[ organization_id name ], unique: true

      t.jsonb :schema, null: false, default: "{}"

      t.timestamps
    end

    fk_organization :jobshop_collections
  end

  private def create_things_table
    create_table_with_auditing :jobshop_things, primary_key: %i[
      organization_id id
    ]do |t|
      t.references :collection, null: false, type: :uuid,
        foreign_key: { to_table: :jobshop_collections }
      t.citext :name
      t.index %i[ organization_id collection_id name ], unique: true,
        name: :idx_jobshop_organization_id_collection_id_name

      t.jsonb :custom_fields, null: false, default: "{}"
      t.index :custom_fields, using: :gin

      t.timestamps
    end

    fk_organization :jobshop_things

    foreign_key :jobshop_things, :jobshop_collections,
      { organization_id: :organization_id, collection_id: :id }
  end
end
