# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateRoutingProcesses < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_routing_processes_table
    create_routing_process_instances_table
    create_routing_steps_table
  end

  private def create_routing_processes_table
    create_table_with_auditing :jobshop_routing_processes, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :product, type: :uuid, null: false,
        foreign_key: { to_table: :jobshop_products }
    end

    fk_organization :jobshop_routing_processes

    foreign_key :jobshop_routing_processes, :jobshop_products,
      { organization_id: :organization_id, product_id: :id }
  end

  private def create_routing_process_instances_table
    create_table_with_auditing :jobshop_routing_process_instances, primary_key: %i[
      organization_id routing_process_id id
    ] do |t|
      t.timestamps
    end

    fk_organization :jobshop_routing_process_instances
  end

  private def create_routing_steps_table
    create_table_with_auditing :jobshop_routing_steps, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :routing_process, type: :uuid, null: false,
        foreign_key: { to_table: :jobshop_routing_processes }

      t.citext :name
      t.index %i[ organization_id name ]
    end

    fk_organization :jobshop_routing_steps

    foreign_key :jobshop_routing_steps, :jobshop_routing_processes,
      { organization_id: :organization_id, routing_process_id: :id }
  end
end
