# frozen_string_literal: true

require "jobshop/helpers/migration.rb"

class CreateDepartments < ActiveRecord::Migration[5.2]
  include Jobshop::Helpers::Migration

  def change
    create_departments_table
    create_department_assignments_table
  end

  private def create_departments_table
    create_table_with_auditing :jobshop_departments, primary_key: %i[
      organization_id id
    ] do |t|
      t.citext :name

      t.timestamps
    end
  end

  private def create_department_assignments_table
    create_table_with_auditing :jobshop_department_assignments, primary_key: %i[
      organization_id id
    ] do |t|
      t.references :department, type: :uuid,
        foreign_key: { to_table: :jobshop_departments }
      t.references :employee, type: :uuid,
        foreign_key: { to_table: :jobshop_employees }

      t.index %i[ organization_id department_id employee_id ], unique: true,
        name: :idx_jobshop_department_assignments_department_id_employee_id
    end

    fk_organization :jobshop_department_assignments
  end
end
