# frozen_string_literal: true

require "thor"
require "jobshop/cli/application"
require "jobshop/cli/canary"
require "jobshop/cli/app_generator"
require "jobshop/version"

module Jobshop
  module CLI
    class << self
      def start(argv = ARGV)
        if [ "-v", "--version" ].include?(argv[0])
          puts "Jobshop #{Jobshop.gem_version}"
          puts Gem.loaded_specs["jobshop"].full_gem_path
          exit 0
        end

        if application?
          Jobshop::CLI::Application.start(argv)
        elsif canary?
          Jobshop::CLI::Canary.start(argv)
        else
          Jobshop::CLI::AppGenerator.start(argv)
        end
      end

      def application?
        has_executable? && !has_gemspec?
      end

      def canary?
        has_executable? && has_gemspec?
      end

      private def has_executable?
        @has_executable ||= File.file?("bin/jobshop")
      end

      private def has_gemspec?
        @jobshop_development ||= File.file?("jobshop.gemspec")
      end
    end
  end
end
