module Jobshop
  class Configuration
    extend Forwardable

    attr_accessor :aws, :smtp, :mailer_host, :session_store_url

    def initialize
      self.mailer_host = ENV.fetch("JOBSHOP_MAILER_HOST", "https://jobshop.test:8443")
      self.session_store_url = ENV.fetch("JOBSHOP_SESSION_STORE_URL", "")

      self.aws = ActiveSupport::OrderedOptions.new
      self.aws.access_key_id = ENV.fetch("JOBSHOP_AWS_ACCESS_KEY_ID", "")
      self.aws.secret_access_key =
        ENV.fetch("JOBSHOP_AWS_SECRET_ACCESS_KEY", "")
      self.aws.region = ENV.fetch("JOBSHOP_AWS_REGION", "")
      self.aws.s3_bucket = ENV.fetch("JOBSHOP_S3_BUCKET", "")
      self.aws.incoming_email_queue =
        ENV.fetch("JOBSHOP_INCOMING_EMAIL_QUEUE", "")

      self.smtp = ActiveSupport::OrderedOptions.new
      self.smtp.address = ENV.fetch("JOBSHOP_SES_SMTP_ADDRESS", "")
      self.smtp.port = ENV.fetch("JOBSHOP_SES_SMTP_PORT", 587)
      self.smtp.user_name = ENV.fetch("JOBSHOP_SES_SMTP_USERNAME", "")
      self.smtp.password = ENV.fetch("JOBSHOP_SES_SMTP_PASSWORD", "")
      self.smtp.default_from =
        ENV.fetch("JOBSHOP_SES_SMTP_DEFAULT_FROM", "noreply@jobshop.test")
    end
  end

  class << self
    attr_writer :configuration

    def configuration
      @configuration ||= Configuration.new
    end

    def configure
      yield configuration
    end
  end
end
