# frozen_string_literal: true

require "devise"
require "haml-rails"
require "sass-rails"
require "statesman"
require "unitwise"
require "wisper"

module Jobshop
  class Engine < ::Rails::Engine
    isolate_namespace Jobshop

    config.eager_load_namespaces << Jobshop

    config.generators do |g|
      g.orm :active_record, primary_key_type: :uuid
      g.orm :active_record, foreign_key_type: :uuid
      g.test_framework :rspec, view_specs: false
      g.helper false
      g.javascripts false
      g.stylesheets false
    end

    ActiveSupport::Inflector.inflections do |inflect|
      inflect.irregular "criterion", "criteria"
      inflect.acronym "RFQs"
      inflect.acronym "RFQ"
    end

    initializer "jobshop.append_paths", before: :load_config_initializers do
      config.paths["db/migrate"].expanded.each do |expanded_path|
        Rails.application.config.paths["db/migrate"] << expanded_path
      end
    end

    initializer "jobshop.active_record_on_load" do
      ActiveSupport.on_load(:active_record) do
        require "activerecord_json_validator"
        require "fast_jsonapi"
      end
    end

    initializer "jobshop.action_mailer_on_load" do
      ActiveSupport.on_load(:action_mailer) do
        ActionMailer::Base.smtp_settings = {
          address: Jobshop.configuration.smtp.address,
          port: Jobshop.configuration.smtp.port,
          user_name: Jobshop.configuration.smtp.user_name,
          password: Jobshop.configuration.smtp.password,
          authentication: :login,
          enable_starttls_auto: true
        }

        ActionMailer::Base.default_options = {
          from: Jobshop.configuration.smtp.default_from
        }

        ActionMailer::Base.default_url_options = {
          host: Jobshop.configuration.mailer_host
        }
      end
    end

    initializer "jobshop.redis" do
      #require "redis-rails"

      Rails.application.config.session_store :cookie_store,
        key: "_your_app_session"
      #(:redis_store, {
      #  servers: Jobshop.configuration.session_store_url
      #})
    end

    initializer "jobshop.aws.config" do
      require "aws-sdk-core"

      Aws.config.update({
        credentials: Aws::Credentials.new(
          Jobshop.configuration.aws.access_key_id,
          Jobshop.configuration.aws.secret_access_key
        ),
        region: Jobshop.configuration.aws.region
      })
    end
  end
end
