# frozen_string_literal: true

module Jobshop
  module  Mailroom
    class RFQHandler < BaseHandler
      self.archive_prefix = "rfqs/processed"

      def process
        new_rfq = organization.rfqs.create!({
          requested_by: customer_contact,
          customer: customer,
          from: from,
          subject: subject,
          content: content
        })

        if customer_contact
          RFQResponderMailer.with(customer_contact: customer_contact)
            .verified_contact.deliver_later
        end
        # TODO: Send rfq to quoting queue with low priority if customer.nil?
        return new_rfq
      end

      private def from_domain
        [ "reverse(lower(email_from_domain)) LIKE ?",
          "#{from.domain.reverse.downcase}%" ]
      end

      private def parse_body(message)
        if message.multipart?
          message.parts[0].decode_body
        else
          message.decode_body
        end
      end
    end
  end
end
